
/*
	Francisco Rodriguez Alfaro - fran@datamanagement.es
	Carga los datos en la dimensin dw_dim_fecha

	CREATE TABLE dw_dim_fecha (
		id_fecha int primary key
		, fecha date 
		, ano int
		, trimestre char(2)
		, ano_trimestre varchar(10)
		, mes varchar(2)
		, ano_mes varchar(10)
		, dia varchar(2)
		, dia_semana_number int
		, dia_semana_desc varchar(20)
	)

*/
CREATE PROCEDURE CargarDatos_DW_DIM_FECHA(
	@fecha_ini date = '2018-01-01'
	, @fecha_fin date = '2018-06-28'
)
AS
Begin

	declare @fechas_tabla table (
		fecha date
	)

	declare @dias_diferencia int = DATEDIFF(DAY, @fecha_ini, @fecha_fin)	-- Obtener los dias de diferencia
	declare @index int = 0
	declare @fecha_aux date

	-- select @fecha_ini, @fecha_fin, @dias_diferencia
	WHILE @index <= @dias_diferencia BEGIN

		set @fecha_aux = DATEADD(DAY, @index, @fecha_ini)
		insert into @fechas_tabla (fecha)
		values ( @fecha_aux )

		SET @index = @index + 1 
	END 

	-- Truncar la tabla antes de insertar datos
	TRUNCATE TABLE dw_dim_fecha;

	INSERT INTO dw_dim_fecha ( id_fecha, fecha, ano, trimestre, ano_trimestre, mes, ano_mes, dia, dia_semana_number, dia_semana_desc  )
	SELECT 
		CAST( DATEPART( yyyy, fecha  ) AS VARCHAR ) 
			+  Right('0' + Cast(  DATEPART( mm, fecha) As varchar(5)), 2)
			+  Right('0' + Cast(  DATEPART( dd, fecha) As varchar(5)), 2) AS 'ID_FECHA'
		, fecha 
		, DATEPART( yyyy, fecha  ) as 'ano'
		, Right('0' + Cast(  DATEPART( Qq, fecha) As varchar(5)), 2) AS 'TRIMESTRE'
		, CAST( DATEPART( yyyy, fecha  ) AS VARCHAR ) 
			+ '-' +  Right('0' + Cast(  DATEPART( Qq, fecha) As varchar(5)), 5) AS 'ANO_TRIMESTRE'
		, Right('0' + Cast(  DATEPART( mm, fecha) As varchar(5)), 2) AS 'MES'
		, CAST( DATEPART( yyyy, fecha  ) AS VARCHAR ) 
			+ '-' +  Right('0' + Cast(  DATEPART( mm, fecha) As varchar(5)), 2) AS 'ANO_MES'
		, Right('0' + Cast(  DATEPART( dd, fecha) As varchar(5)), 2) AS 'DIA'
		, DATEPART( dw, fecha  ) as 'dia_number'
		, CASE 
			WHEN ( DATEPART( dw, fecha  ) = 1 ) THEN 
				'Lunes'
			WHEN ( DATEPART( dw, fecha  ) = 2 ) THEN 
				'Martes'
			WHEN ( DATEPART( dw, fecha  ) = 3 ) THEN 
				'Mircoles'
			WHEN ( DATEPART( dw, fecha  ) = 4 ) THEN 
				'Jueves'
			WHEN ( DATEPART( dw, fecha  ) = 5 ) THEN 
				'Viernes'
			WHEN ( DATEPART( dw, fecha  ) = 6 ) THEN 
				'Sbado'
			WHEN ( DATEPART( dw, fecha  ) = 7 ) THEN 
				'Domingo'
			END as 'dia_semana_desc'
	FROM @fechas_tabla


END -- Cerrar procedimiento

/*
EXEC CargarDatos_DW_DIM_FECHA 

EXEC CargarDatos_DW_DIM_FECHA 
	@fecha_ini = '2018-01-01'
	, @fecha_fin = '2018-12-31'
*/








